var Docker = require('dockerode'),
	blessed = require('blessed'),
	contrib = require('blessed-contrib');

var ContainerBox = function(screen, showbox) {
	if (!(this instanceof ContainerBox))
		return new ContainerBox(screen, showbox);
	var self = this;
	this.showbox = showbox;
	this.screen = screen;

	this.table = new contrib.line({
		top: 0,
		left: 'center',
		width: '100%-2',
		height: '40%',
		style: {
			line: 'red',
			text: 'green',
			baseline: ['#696969']
		},
		border: {
			type: "line",
			fg: "cyan"
		},
		showNthLabel: 1,
		showLegend: false,
		wholeNumbersOnly: false,
		label: 'table'
	});

	this.cpu = new contrib.line({
		top: '40%',
		left: 0,
		width: '50%-1',
		height: '30%',
		style: {
			line: 'red',
			text: 'green',
			baseline: ['#696969']
		},
		border: {
			type: "line",
			fg: "cyan"
		},
		showNthLabel: 1,
		showLegend: false,
		wholeNumbersOnly: false,
		label: 'CPU Usage (%)'
	});

	this.mem = new contrib.line({
		top: '40%',
		left: '50%',
		width: '50%-1',
		height: '30%',
		style: {
			line: 'magenta',
			text: 'green',
			baseline: ['#696969']
		},
		border: {
			type: "line",
			fg: "cyan"
		},
		showNthLabel: 1,
		label: 'Memory Usage (MB)',
		xLabelPadding: 3,
		showLegend: false
	});

	this.net = new contrib.line({
		top: '70%',
		left: 0,
		width: '50%-1',
		height: '30%-1',
		style: {
			text: 'green',
			baseline: ['#696969']
		},
		border: {
			type: "line",
			fg: "cyan"
		},
		showLegend: true,
		legend: {
			width: 4
		},
		wholeNumbersOnly: false,
		label: 'Net I/O (KB)'
	});

	this.log = new contrib.line({
		top: '70%',
		left: '50%',
		width: '50%-1',
		height: '30%-1',
		style: {
			text: 'green',
			baseline: ['#696969']
		},
		border: {
			type: "line",
			fg: "cyan"
		},
		showLegend: true,
		legend: {
			width: 4
		},
		wholeNumbersOnly: false,
		label: 'Net I/O (KB)'
	});

	showbox.append(this.table);
	showbox.append(this.cpu);
	showbox.append(this.mem);
	showbox.append(this.net);
	showbox.append(this.log);

	var usage = {
		x: ['1', '2', '3'],
		y: [1, 1, 2]
	}

	this.cpu.setData(usage);


	this.screen.on('resize', function() {
		self.showbox.remove(self.cpu)
		self.showbox.append(self.cpu)
		self.cpu.setData(usage);
		self.screen.render();
	});
}

ContainerBox.prototype.show = function() {
	//this.containerTable.show();
	// this.containerTable.show();
	// this.net.show();
	// this.mem.show();
	this.cpu.show();
	this.screen.render();
}

ContainerBox.prototype.hide = function() {
	// this.containerTable.hide();
	// this.net.hide();
	// this.mem.hide();
	this.cpu.hide();
	this.screen.render();
}


module.exports = ContainerBox;